==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/outputs/ContainerizedNetworkFunctionDefinitionVersionResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Containerized network function network function definition version properties.
 * @property deployParameters The deployment parameters of the network function definition version.
 * @property description The network function definition version description.
 * @property networkFunctionTemplate Containerized network function template.
 * @property networkFunctionType The network function type.
 * Expected value is 'ContainerizedNetworkFunction'.
 * @property provisioningState The provisioning state of the network function definition version resource.
 * @property versionState The network function definition version state.
 */
public data class ContainerizedNetworkFunctionDefinitionVersionResponse(
    public val deployParameters: String? = null,
    public val description: String? = null,
    public val networkFunctionTemplate: AzureArcKubernetesNetworkFunctionTemplateResponse? = null,
    public val networkFunctionType: String,
    public val provisioningState: String,
    public val versionState: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.hybridnetwork.outputs.ContainerizedNetworkFunctionDefinitionVersionResponse):
            ContainerizedNetworkFunctionDefinitionVersionResponse =
            ContainerizedNetworkFunctionDefinitionVersionResponse(
                deployParameters = javaType.deployParameters().map({ args0 -> args0 }).orElse(null),
                description = javaType.description().map({ args0 -> args0 }).orElse(null),
                networkFunctionTemplate = javaType.networkFunctionTemplate().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.hybridnetwork.kotlin.outputs.AzureArcKubernetesNetworkFunctionTemplateResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                networkFunctionType = javaType.networkFunctionType(),
                provisioningState = javaType.provisioningState(),
                versionState = javaType.versionState(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/outputs/ContainerizedNetworkFunctionDefinitionVersionResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Containerized network function network function definition version properties.
 * @property deployParameters The deployment parameters of the network function definition version.
 * @property description The network function definition version description.
 * @property networkFunctionTemplate Containerized network function template.
 * @property networkFunctionType The network function type.
 * Expected value is 'ContainerizedNetworkFunction'.
 * @property provisioningState The provisioning state of the network function definition version resource.
 * @property versionState The network function definition version state.
 */
public data class ContainerizedNetworkFunctionDefinitionVersionResponse(
    public val deployParameters: String? = null,
    public val description: String? = null,
    public val networkFunctionTemplate: AzureArcKubernetesNetworkFunctionTemplateResponse? = null,
    public val networkFunctionType: String,
    public val provisioningState: String,
    public val versionState: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.hybridnetwork.outputs.ContainerizedNetworkFunctionDefinitionVersionResponse): ContainerizedNetworkFunctionDefinitionVersionResponse =
            ContainerizedNetworkFunctionDefinitionVersionResponse(
                deployParameters = javaType.deployParameters().map({ args0 -> args0 }).orElse(null),
                description = javaType.description().map({ args0 -> args0 }).orElse(null),
                networkFunctionTemplate = javaType.networkFunctionTemplate().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.hybridnetwork.kotlin.outputs.AzureArcKubernetesNetworkFunctionTemplateResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                networkFunctionType = javaType.networkFunctionType(),
                provisioningState = javaType.provisioningState(),
                versionState = javaType.versionState(),
            )
    }
}
